<?php
error_reporting(E_ALL);

// Ensure library/ is on include_path
set_include_path(implode(PATH_SEPARATOR, array(
    realpath(dirname(__FILE__) . '/library'),
    get_include_path(),
)));

//register our own autoloading function
function _customAutoload($path) {
    include str_replace('_','/',$path) . '.php';
}
try {
    require_once 'Zend/Loader/Autoloader.php';
    $autoloader = Zend_Loader_Autoloader::getInstance();
    $autoloader->setDefaultAutoloader('_customAutoload');
} catch (Exception $e) {
    die($e->getMessage().'<br />'.$e->getTraceAsString());
}

class ServerService {
    /**
     *
     * @return array
     */
    public function getServerLoad() {
        if (file_exists('/proc/loadavg')) {
            $loadavg = file_get_contents('/proc/loadavg');
            return explode(' ', $loadavg);
        } else {
            throw new Exception('Metrics not available',-32099);
        }
    }
    /**
     * @param string
     * @return string
     */
    public function getNetworkLoad($type = 'rx') {
        switch($type) {
            case 'rx':
                $rx = 0;
                if (file_exists('/sys/class/net/wlan0/statistics/rx_bytes')) {
                    $rx = file_get_contents('/sys/class/net/wlan0/statistics/rx_bytes');
                } elseif (file_exists('/sys/class/net/eth0/statistics/rx_bytes')) {
                    $rx = file_get_contents('/sys/class/net/eth0/statistics/rx_bytes');
                } elseif (file_exists('/sys/class/net/eth1/statistics/rx_bytes')) {
                    $rx = file_get_contents('/sys/class/net/eth1/statistics/rx_bytes');
                }
                return trim($rx);
                break;
            case 'tx':
                $tx = 0;
                if (file_exists('/sys/class/net/wlan0/statistics/tx_bytes')) {
                    $tx = file_get_contents('/sys/class/net/wlan0/statistics/tx_bytes');
                } elseif (file_exists('/sys/class/net/eth0/statistics/tx_bytes')) {
                    $tx = file_get_contents('/sys/class/net/eth0/statistics/tx_bytes');
                } elseif (file_exists('/sys/class/net/eth1/statistics/tx_bytes')) {
                    $tx = file_get_contents('/sys/class/net/eth1/statistics/tx_bytes');
                }
                return trim($tx);
                break;
            default:
                return '0';
                break;
        }
    }
    /**
     * @param lines
     * @return string
     */
    public function getTopOutput($lines = 20) {
        $result = array();
        exec('top -b -n 1',$result);
        if (count($result) > $lines) {
            return implode(PHP_EOL,array_slice($result,0,$lines));
        }
        return implode(PHP_EOL,$result);
    }
}

try {
    $cacheFile = dirname(__FILE__) . '/jsonrpc.cache';
    $server = new Zend_Json_Server();
    $server->setClass('ServerService');

    if ('GET' == $_SERVER['REQUEST_METHOD']) {
        if (!($smd = Zend_Json_Server_Cache::getSmd($cacheFile, $server))) {
            Zend_Json_Server_Cache::saveSmd($cacheFile, $server);
            $smd = $server->getServiceMap();
        }
        $server->setTarget('./SERVER.php');
        header('Content-Type: application/json');
        header("Content-Disposition:attachment;filename=service.smd");
        echo $smd;
        return;
    }
    //$server->handle();
    $request = new Zend_Json_Server_Request_Http();
    $server->setAutoEmitResponse(false);
    $response = $server->handle($request);
    echo $response;
} catch (Exception $e) {
    die($e->getMessage().'<br />'.$e->getTraceAsString());
}
